@@ -6,20 +6,22 @@ Sys.info <- function(...) base::Sys.info(...)
 
 test_that("canCallIEDriver", {
   with_mock(
-    `binman::process_yaml` = function(...){},
+    `binman::process_yaml` = function(...) {},
     `binman::list_versions` = mock_binman_list_versions_iedriver,
     `binman::app_dir` = mock_binman_app_dir,
-     normalizePath = mock_base_normalizePath,
-     list.files = mock_base_list.files,
+    normalizePath = mock_base_normalizePath,
+    list.files = mock_base_list.files,
     `subprocess::spawn_process` = mock_subprocess_spawn_process,
     `subprocess::process_return_code` =
       mock_subprocess_process_return_code,
     `subprocess::process_kill` = mock_subprocess_process_kill,
-      Sys.info = function(...){
+    Sys.info = function(...) {
       structure("Windows", .Names = "sysname")
     },
     `wdman:::generic_start_log` = mock_generic_start_log,
-    `wdman:::infun_read` = function(...){"infun"},
+    `wdman:::infun_read` = function(...) {
+      "infun"
+    },
     {
       ieDrv <- iedriver()
       retCommand <- iedriver(retcommand = TRUE)
@@ -48,48 +50,54 @@ test_that("iedriver_verErrorWorks", {
 
 test_that("pickUpErrorFromReturnCode", {
   with_mock(
-    `binman::process_yaml` = function(...){},
+    `binman::process_yaml` = function(...) {},
     `binman::list_versions` = mock_binman_list_versions_iedriver,
     `binman::app_dir` = mock_binman_app_dir,
-     normalizePath = mock_base_normalizePath,
-     list.files = mock_base_list.files,
+    normalizePath = mock_base_normalizePath,
+    list.files = mock_base_list.files,
     `subprocess::spawn_process` = mock_subprocess_spawn_process,
-    `subprocess::process_return_code` = function(...){"some error"},
+    `subprocess::process_return_code` = function(...) {
+      "some error"
+    },
     `subprocess::process_read` =
       mock_subprocess_process_read_selenium,
     `wdman:::generic_start_log` = mock_generic_start_log,
-     Sys.info = function(...){
+    Sys.info = function(...) {
       structure("Windows", .Names = "sysname")
     },
     {
-      expect_error(iedriver(version = "3.0.0"),
-                   "iedriver couldn't be started")
+      expect_error(
+        iedriver(version = "3.0.0"),
+        "iedriver couldn't be started"
+      )
     }
   )
 })
 
 test_that("pickUpErrorFromPortInUse", {
   with_mock(
-    `binman::process_yaml` = function(...){},
+    `binman::process_yaml` = function(...) {},
     `binman::list_versions` = mock_binman_list_versions_iedriver,
     `binman::app_dir` = mock_binman_app_dir,
-     normalizePath = mock_base_normalizePath,
-     list.files = mock_base_list.files,
+    normalizePath = mock_base_normalizePath,
+    list.files = mock_base_list.files,
     `subprocess::spawn_process` = mock_subprocess_spawn_process,
     `subprocess::process_return_code` =
       mock_subprocess_process_return_code,
     `subprocess::process_read` =
       mock_subprocess_process_read_selenium,
     `subprocess::process_kill` = mock_subprocess_process_kill,
-    `wdman:::generic_start_log` = function(...){
+    `wdman:::generic_start_log` = function(...) {
       list(stderr = "Address in use")
     },
-    Sys.info = function(...){
+    Sys.info = function(...) {
       structure("Windows", .Names = "sysname")
     },
     {
-      expect_error(iedriver(version = "3.0.0"),
-                   "IE Driver signals port")
+      expect_error(
+        iedriver(version = "3.0.0"),
+        "IE Driver signals port"
+      )
     }
   )
 })
